@@ -9,7 +9,8 @@ use Carp qw/croak/;
 use WWW::Curl::Simple::Request;
 use WWW::Curl::Multi;
 use WWW::Curl::Easy;
-use Sub::Alias;
+
+#use base 'LWP::Parallel::UserAgent';
 
 use namespace::clean -except => 'meta';
 
@@ -19,7 +20,7 @@ WWW::Curl::Simple - A simpler interface to WWW::Curl
 
 =head1 VERSION
 
-Version 0.01
+Version 0.02
 
 =head1 SYNOPSIS
 
@@ -36,7 +37,7 @@ Perhaps a little code snippet.
 
 =cut
 
-our $VERSION = '0.01';
+our $VERSION = '0.03';
 
 
 =head3 request($req)
@@ -54,7 +55,6 @@ sub request {
     
     # Starts the actual request
     return $curl->perform;
-
 }
 
 
@@ -70,6 +70,14 @@ sub get {
     return $self->request(HTTP::Request->new(GET => $uri));
 }
 
+=head3 post($uri || URI, $form)
+
+Created a HTTP::Request of type POST to $uri, which can be a string
+or a URI object, and sets the form of the request to $form. See
+L<HTTP::Request> for more information on the format of $form
+
+=cut
+
 sub post {
     my ($self, $uri, $form) = @_;
     
@@ -101,7 +109,9 @@ sub add_request {
     $self->_add_request(WWW::Curl::Simple::Request->new(request => $req));
 }
 
-alias register => 'add_request';
+__PACKAGE__->meta->add_package_symbol('&register',
+    __PACKAGE__->meta->get_package_symbol('&add_request')
+);
 
 =head3 perform
 
@@ -109,7 +119,6 @@ Does all the requests added with add_request, and returns a
 list of HTTP::Response-objects
 
 =cut
-alias wait => 'perform';
 
 sub perform {
     my ($self) = @_;
@@ -135,11 +144,10 @@ sub perform {
                 if ($id) {
                     $i--;
                     my $req = $reqs{$id};
-                    
                     unless ($retcode == 0) {
                         croak("Error during handeling of request: " .$req->easy->strerror($retcode)." ". $req->request->uri);
                     }
-                    push(@res, $req->response);
+                    push(@res, $req);
                     delete($reqs{$id});
                 }
             }
@@ -148,6 +156,36 @@ sub perform {
     return @res;
 }
 
+=head3 LWP::Parallel::UserAgent compliant methods
+
+=over
+
+=item wait
+
+These methods are here to provide an easier transition from
+L<LWP::Parallel::UserAgent>. It is by no means a drop in replacement,
+but using C<wait> instead of C<perform> makes the return-value perform
+more alike
+
+=back
+=cut
+
+sub wait {
+    my $self = shift;
+    
+    my @res = $self->perform(@_);
+    
+    # convert to a hash
+    my %res;
+    
+    while (my $r = pop @res) {
+        #warn "adding $r at " . scalar(@res);
+        $res{scalar(@res)} = $r;
+    }
+    
+    return \%res;
+}
+
 =head1 AUTHOR
 
 Andreas Marienborg, C<< <andreas at startsiden.no> >>
